========
pymipago
========


.. image:: https://img.shields.io/pypi/v/pymipago.svg
        :target: https://pypi.python.org/pypi/pymipago

.. image:: https://travis-ci.org/codesyntax/pymipago.svg?branch=master
        :target: https://travis-ci.org/codesyntax/pymipago

.. image:: https://coveralls.io/repos/github/codesyntax/pymipago/badge.svg?branch=master
        :target: https://coveralls.io/github/codesyntax/pymipago?branch=master

.. image:: https://readthedocs.org/projects/pymipago/badge/?version=latest
        :target: https://pymipago.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/codesyntax/pymipago/shield.svg
     :target: https://pyup.io/repos/github/codesyntax/pymipago/
     :alt: Updates



Python package to make payment requests with Basque Government's payment service


* Free software: GNU General Public License v3
* Documentation: https://pymipago.readthedocs.io.


Features
--------

This package allows to use the `Basque Governent's Payment Service`_, a platform
that allows Basque public institutions to receive payments from the citizens.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage


The development of this package was funded by `AMETX Erakunde Autonomoa`_

.. _`AMETX Erakunde Autonomoa`: https://www.ametx.eus
.. _`Basque Governent's Payment Service`: https://www.euskadi.eus/mipago
